/**
 * Kivu4j. Copyright (C) 2010 . see<http://kivu4j.sourceforge.net />

   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses />.
 */

package net.sourceforge.kivu4j.utils.action;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * 有数据（可以是多条）的结果数据。返回给客户端向这样的：
 * 
 * <pre>
 * {
 * 	success:false,
 * 	start:0,
 *  limit:0,
 *  total:16,
 *  more:true,
 *  data:[{...},{...},{...}]
 * }
 * </pre>
 * 
 * @author Lucky Yang
 */
public class ResponseList<E extends Object> extends ResponseData{
	/**
	 * 
	 */
	private static final long serialVersionUID = 922689479883110446L;
	private List<E> data = new ArrayList<E>();

	public ResponseList() {
		super();
	}
	
	public ResponseList(E data) {
		super();
		if (data != null)
			this.data.add(data);
	}

	public ResponseList(Collection<E> data) {
		super();
		if (data != null){
			this.data.addAll(data);
		}
	}

	public Collection<E> getData() {
		return data;
	}

	@Override
	public void doPagination() {
		int size = this.data.size();
			
		if (this.getLimit() <= 0) { 
			// 不需要分页，全部返回
			this.setTotal(size);
			this.setMore(false);
		}
		else {		
			if (size > this.getLimit()){
				// 存在下一页
				this.setMore(true);
				this.data.remove(size - 1);
			}
			else
				this.setMore(false);
			
			int total = size + this.getStart();
			if (total > this.getTotal()){
				// 保留最大的记录数。前翻时，记录数保持不变
				this.setTotal(total);
			}
		}	
	}
	
}